package org.fouram.service;

import java.util.Iterator;
import java.util.List;

import org.fouram.core.base.service.BaseService;
import org.fouram.core.util.JsonNodeUtil;
import org.fouram.entity.SapPerPersonRelationship;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import com.fasterxml.jackson.databind.JsonNode;

@Service
public class SapPerPersonRelationshipService extends BaseService {

	public void saveSapData() throws Exception {
		HttpHeaders headers = getHttpHeaders();

		delete("SapPerPersonRelationshipMapper.deleteAll", null);

		String url = "https://api15.sapsf.cn/odata/v2/PerPersonRelationship?$format=json&$expand=relPersonNav";
		JsonNode node = requestService.getForObject(url, headers);
		if (node != null) {
			Iterator<JsonNode> iterator = node.get("d").get("results").elements();
			while (iterator.hasNext()) {
				JsonNode userNode = iterator.next();
				String personId = JsonNodeUtil.getValue(userNode, "personIdExternal");
				String relatedPersonId = JsonNodeUtil.getValue(userNode, "relatedPersonIdExternal");
				String firstName = JsonNodeUtil.getValue(userNode, "firstName");
				String lastName = JsonNodeUtil.getValue(userNode, "lastName");
				String relationshipType = JsonNodeUtil.getValue(userNode, "relationshipType");
				String relationshipTypeName = getLabelValue(relationshipType);
				String dateOfBirth = JsonNodeUtil.getValue(userNode, "relPersonNav", "dateOfBirth");
				SapPerPersonRelationship entity = SapPerPersonRelationship.builder().personId(personId)
						.relatedPersonId(relatedPersonId).lastName(lastName).firstName(firstName)
						.relationshipType(relationshipType).relationshipTypeName(relationshipTypeName)
						.dateOfBirth(dateOfBirth).build();
				save("SapPerPersonRelationshipMapper.save", entity);
			}
		}
	}

	@SuppressWarnings("unchecked")
	public List<SapPerPersonRelationship> findListByPersonId(String personId) throws Exception {
		return (List<SapPerPersonRelationship>) findList("SapPerPersonRelationshipMapper.findListByPersonId", personId);
	}
}
